==> lptk-debug-0.5.0-1-x86_64.pkg.tar.zst: usr/src/debug/lptk/lptk/src/application.rs <==
//
// LPTK application.rs
// Copyright (C) 2025 Óscar García Amor <ogarcia@connectical.com>
// Distributed under terms of the GNU GPLv3 license.
//

use gettextrs::gettext;
use adw::prelude::*;
use adw::subclass::prelude::*;
use gtk::{gio, glib};

use crate::config::{APP_ID, VERSION};
use crate::LptkWindow;

mod imp {
    use super::*;

    #[derive(Debug, Default)]
    pub struct LptkApplication {}

    #[glib::object_subclass]
    impl ObjectSubclass for LptkApplication {
        const NAME: &'static str = "LptkApplication";
        type Type = super::LptkApplication;
        type ParentType = adw::Application;
    }

    impl ObjectImpl for LptkApplication {
        fn constructed(&self) {
            self.parent_constructed();
            let obj = self.obj();
            obj.setup_gactions();
            obj.set_accels_for_action("win.delete", &["<Shift>Delete"]);
            obj.set_accels_for_action("win.save", &["<primary>s"]);
            obj.set_accels_for_action("win.preferences", &["<primary>comma"]);
            obj.set_accels_for_action("app.quit", &["<primary>q"]);
        }
    }

    impl ApplicationImpl for LptkApplication {
        // We connect to the activate callback to create a window when the application
        // has been launched. Additionally, this callback notifies us when the user
        // tries to launch a "second instance" of the application. When they try
        // to do that, we'll just present any existing window.
        fn activate(&self) {
            let application = self.obj();
            // Get the current window or create one if necessary
            let window = application.active_window().unwrap_or_else(|| {
                let window = LptkWindow::new(&*application);
                window.upcast()
            });

            // Ask the window manager/compositor to present the window
            window.present();
        }
    }

    impl GtkApplicationImpl for LptkApplication {}
    impl AdwApplicationImpl for LptkApplication {}
}

glib::wrapper! {
    pub struct LptkApplication(ObjectSubclass<imp::LptkApplication>)
        @extends gio::Application, gtk::Application, adw::Application,
        @implements gio::ActionGroup, gio::ActionMap;
}

impl LptkApplication {
    pub fn new(application_id: &str, flags: &gio::ApplicationFlags) -> Self {
        glib::Object::builder()
            .property("application-id", application_id)
            .property("flags", flags)
            .build()
    }

    fn setup_gactions(&self) {
        let quit_action = gio::ActionEntry::builder("quit")
            .activate(move |app: &Self, _, _| app.quit())
            .build();
        let about_action = gio::ActionEntry::builder("about")
            .activate(move |app: &Self, _, _| app.show_about())
            .build();
        self.add_action_entries([quit_action, about_action]);
    }

    fn show_about(&self) {
        let window = self.active_window().unwrap();
        let about = adw::AboutDialog::builder()
            .application_name("lptk")
            .application_icon(APP_ID)
            .developer_name("Óscar García Amor")
            .version(VERSION)
            .developers(vec!["Óscar García Amor"])
            // Translators: Replace "translator-credits" with your name/username, and optionally an email or URL.
            .translator_credits(&gettext("translator-credits"))
            .copyright("© 2025 Óscar García Amor")
            .build();

        about.present(Some(&window));
    }
}

==> lptk-debug-0.6.0-1-x86_64.pkg.tar.zst: usr/src/debug/lptk/lptk/src/application.rs <==
//
// LPTK application.rs
// Copyright (C) 2025 Óscar García Amor <ogarcia@connectical.com>
// Distributed under terms of the GNU GPLv3 license.
//

use gettextrs::gettext;
use adw::prelude::*;
use adw::subclass::prelude::*;
use gtk::{gio, glib};

use crate::config::{APP_ID, VERSION};
use crate::LptkWindow;

mod imp {
    use super::*;

    #[derive(Debug, Default)]
    pub struct LptkApplication {}

    #[glib::object_subclass]
    impl ObjectSubclass for LptkApplication {
        const NAME: &'static str = "LptkApplication";
        type Type = super::LptkApplication;
        type ParentType = adw::Application;
    }

    impl ObjectImpl for LptkApplication {
        fn constructed(&self) {
            self.parent_constructed();
            let obj = self.obj();
            obj.setup_gactions();
            obj.set_accels_for_action("win.delete", &["<Shift>Delete"]);
            obj.set_accels_for_action("win.save", &["<primary>s"]);
            obj.set_accels_for_action("win.preferences", &["<primary>comma"]);
            obj.set_accels_for_action("app.quit", &["<primary>q"]);
        }
    }

    impl ApplicationImpl for LptkApplication {
        // We connect to the activate callback to create a window when the application
        // has been launched. Additionally, this callback notifies us when the user
        // tries to launch a "second instance" of the application. When they try
        // to do that, we'll just present any existing window.
        fn activate(&self) {
            let application = self.obj();
            // Get the current window or create one if necessary
            let window = application.active_window().unwrap_or_else(|| {
                let window = LptkWindow::new(&*application);
                window.upcast()
            });

            // Ask the window manager/compositor to present the window
            window.present();
        }
    }

    impl GtkApplicationImpl for LptkApplication {}
    impl AdwApplicationImpl for LptkApplication {}
}

glib::wrapper! {
    pub struct LptkApplication(ObjectSubclass<imp::LptkApplication>)
        @extends gio::Application, gtk::Application, adw::Application,
        @implements gio::ActionGroup, gio::ActionMap;
}

impl LptkApplication {
    pub fn new(application_id: &str, flags: &gio::ApplicationFlags) -> Self {
        glib::Object::builder()
            .property("application-id", application_id)
            .property("flags", flags)
            .build()
    }

    fn setup_gactions(&self) {
        let quit_action = gio::ActionEntry::builder("quit")
            .activate(move |app: &Self, _, _| app.quit())
            .build();
        let about_action = gio::ActionEntry::builder("about")
            .activate(move |app: &Self, _, _| app.show_about())
            .build();
        self.add_action_entries([quit_action, about_action]);
    }

    fn show_about(&self) {
        let window = self.active_window().unwrap();
        let about = adw::AboutDialog::builder()
            .application_name("lptk")
            .application_icon(APP_ID)
            .developer_name("Óscar García Amor")
            .version(VERSION)
            .developers(vec!["Óscar García Amor"])
            // Translators: Replace "translator-credits" with your name/username, and optionally an email or URL.
            .translator_credits(gettext("translator-credits"))
            .copyright("© 2025 Óscar García Amor")
            .build();

        about.present(Some(&window));
    }
}
